a {
	text-decoration: none;
	color: #000000;
}

a:hover {
	text-decoration: underline;
	color: #3163CE;
}

.year {
	border-style: outset;
	border-width: 1px;
	text-align: center;
}

.month {
	border-style: none;
	background-color: rgb(222, 222, 222);
	text-align: center;
}

.yearname {
	text-align: center;
	font-size: 18px;
	font-weight: bold;
}

.monthname {
	text-align: center;
	font-size: 13px;
	font-weight: bold;
	background-color: #FFCC00;
	color: #3A0B88;
	border: 1px solid rgb(255, 180, 0);
}

.dayname {
	text-align: center;
	font-size: 12px;
	font-style: italic;
	background-color: rgb(215, 215, 215);
	color: rgb(75, 75, 75);
	border-style: outset;
	border-width:0px
}

.weeknumtitle {
	text-align: center;
	font-size: 12px;
	font-weight: normal;
	background-color: #e9e9e9;
	border-style: outset;
	border-width:1px
}

.weeknum {
	text-align: center;
	font-size: 10px;
	color: #000099;
	background-color: #e9e9e9;
}

.yearnavigation {
	font-size: 12px;
}

.datepicker {
	background-color: #e4e4e4;
}

.datepickerform {
	margin: 0px;
}

.monthnavigation {
	font-family: Tahoma, Arial, sans-serif;
}

.monthpicker {
	font-size: 11px;
	background-color: #eeeeee;
}

.yearpicker {
	font-size: 11px;
	background-color: #eeeeee;
}

.pickerbutton {
	font-size: 11px;
	background-color: #eeeeee;
	border-style: solid;
	border-color: #000000;
	border-width: 1px;
}

.nomonthday {
	text-align: center;
	font-size: 10px;
	color: #aaaaaa;
}

.monthday {
	text-align: center;
	font-size: 11px;
	font-weight: normal;
	background-color: #ffffff;
	color: #000000;
}

.today {
	text-align: center;
	font-size: 11px;
	font-weight: bold;
	background-color: #DDDDDD;
	color: #ffffff;
}

.selectedday {
	text-align: center;
	font-size: 11px;
	font-weight: bold;
	background-color: #66ff66;
}

.sunday {
	text-align: center;
	font-size: 11px;
	font-weight: normal;
	color: #667171;
	background-color: rgb(230, 230, 230);
}

.sunday a {
	color: #667171;
}

.saturday {
	text-align: center;
	font-size: 11px;
	font-weight: normal;
	color: #667171;
	background-color: rgb(230, 230, 230);
}

.saturday a {
	color: #667171;
}

.err_log {
	text-align: center;
	font-size: 11px;
	font-weight: bold;
	color: red;
	background-color: #ffff99;
}

.err_log a {
	background-color: #ffff99;
	color: red;
}

.ok_log {
	text-align: center;
	font-size: 11px;
	font-weight: bold;
	color: green;
	background-color: #ffff99;
}

.ok_log a {
	background-color: #ffff99;
	color: green;
}

.todayerr_log {
        text-align: center;
        font-size: 14px;
        font-weight: bold;
        color: red;
        background-color: #ffff99;
        border-style: solid;
        border-color:  #ffb400;
        border-width: 1px;
}
.todayerr_log a {
        background-color: #ffff99;
        color: red;
}

.todayok_log {
        text-align: center;
        font-size: 14px;
        font-weight: bold;
        color: green;
        background-color: #ffff99;
        border-style: solid;
        border-color:  #ffb400;
        border-width: 1px;
}
.todayok_log a {
        background-color: #ffff99;
        color: green;
}


.selectedevent {
	text-align: center;
	font-size: 11px;
	font-weight: bold;
	color: red;
	background-color: #ffff99;
}

.selectedevent a {
	background-color: #ffff99;
	color: red;
}

.todayevent {
	text-align: center;
	font-size: 11px;
	font-weight: bold;
	color: red;
	background-color: #ffff99;
}

.todayevent a {
	background-color: #ffff99;
	color: red;
}

.eventcontent {
	font-size: 10px;
	border-style: outset;
	border-width: 1px;
	width: 100%;
}
